@@ -42,6 +42,11 @@ sub run($;$)
     }
 }
 
+sub configuration
+{
+    die "This placeholder shouldn't be called.";
+}
+
 no Moose;    # gets rid of scaffolding
 
 # Return package name instead of 1 or otherwise worker.pl won't know the name of the package it's loading
